@@ -10,7 +10,7 @@ use Apache::Session::Serialize::JSON;
 use Apache::Session::Browseable::_common;
 use Net::LDAP::Util qw(escape_filter_value);
 
-our $VERSION = '1.3.6';
+our $VERSION = '1.2';
 our @ISA     = qw(Apache::Session Apache::Session::Browseable::_common);
 
 sub populate {
@@ -84,7 +84,6 @@ sub _query {
     );
 
     $ldap->unbind();
-    $ldap->disconnect();
 
     if ( $msg->code ) {
         Apache::Session::Browseable::Store::LDAP->logError($msg);
@@ -181,8 +180,6 @@ Apache::Session::Browseable::LDAP - An implementation of Apache::Session::LDAP
     ldapAttributeId      => 'cn',
     ldapAttributeContent => 'description',
     ldapAttributeIndex   => 'ou',
-    ldapVerify           => 'require',
-    ldapCAFile           => '/etc/ssl/certs/ca-certificates.crt',
   };
 
 =head1 DESCRIPTION
@@ -198,8 +195,8 @@ Xavier Guimard, E<lt>x.guimard@free.frE<gt>
 
 =encoding utf8
 
-Copyright (C) 2009-2017 by Xavier Guimard
-Copyright (C) 2013-2017 by Clement Oudot
+Copyright (C) 2009 by Xavier Guimard
+Copyright (C) 2013, 2015 by Clement Oudot
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.10.0 or,
