@@ -1,26 +1,24 @@
 package Apache::Session::Browseable::Store::Redis;
 
 use strict;
+use Redis;
 
-our $VERSION = '1.3.18';
-
-our $redis;
-our %reused_connections;
-
-BEGIN {
-    $redis = 'Redis::Fast';
-    eval 'use Redis::Fast';
-    if ($@) {
-        require Redis;
-        $redis = 'Redis';
-    }
-}
+our $VERSION = '1.2';
 
 sub new {
     my ( $class, $session ) = @_;
     my $self;
 
-    $self->{cache} = $class->_getRedis( $session->{args} );
+    # Manage undef encoding
+    $session->{args}->{encoding} = undef
+      if (  $session->{args}->{encoding}
+        and $session->{args}->{encoding} eq "undef" );
+
+    $self->{cache} = Redis->new( %{ $session->{args} } );
+
+    # Manage database
+    $self->{cache}->select( $session->{args}->{database} )
+      if defined $session->{args}->{database};
 
     bless $self, $class;
 }
@@ -35,8 +33,8 @@ sub insert {
     my $id = $session->{data}->{_session_id};
     $self->{cache}->set( $id, $session->{serialized} );
     foreach my $i (@$index) {
-        my $t = $session->{data}->{$i};
-        next unless ( defined($t) and ( length($t) > 0 ) );
+        my $t;
+        next unless ( $t = $session->{data}->{$i} );
         $self->{cache}->sadd( "${i}_$t", $id );
     }
 }
@@ -66,43 +64,6 @@ sub remove {
     $self->{cache}->del($id);
 }
 
-sub _getRedis {
-    my $class = shift;
-    my $args  = shift;
-    my $redisObj;
-
-    # Manage undef encoding
-    $args->{encoding} = undef
-      if (  $args->{encoding}
-        and $args->{encoding} eq "undef" );
-
-    # If sentinels is not given as an array ref, try to parse
-    # a comma delimited list instead
-    if ( $args->{sentinels}
-        and ref $args->{sentinels} ne 'ARRAY' )
-    {
-        $args->{sentinels} =
-          [ split /[,\s]+/, $args->{sentinels} ];
-    }
-
-    if (    $args->{reuse}
-        and $reused_connections{ $args->{reuse} } )
-    {
-        $redisObj = $reused_connections{ $args->{reuse} };
-    }
-    else {
-        $redisObj = $redis->new( %{$args} );
-        if ( $args->{reuse} ) {
-            $reused_connections{ $args->{reuse} } = $redisObj;
-        }
-    }
-
-    # Manage database
-    $redisObj->select( $args->{database} )
-      if defined $args->{database};
-    return $redisObj;
-}
-
 1;
 __END__
 
@@ -127,28 +88,11 @@ Apache::Session::Store
 This module is an implementation of Apache::Session::Browseable. It uses the
 Redis storage system
 
+=head1 AUTHOR
+
+This module was written by Xavier Guimard <x.guimard@free.fr>
+
 =head1 SEE ALSO
 
 L<Apache::Session::Browseable>, L<Apache::Session::NoSQL>, L<Apache::Session>
 
-=head1 COPYRIGHT AND LICENSE
-
-=over
-
-=item 2009-2025 by Xavier Guimard
-
-=item 2013-2025 by Clément Oudot
-
-=item 2019-2025 by Maxime Besson
-
-=item 2013-2025 by Worteks
-
-=item 2023-2025 by Linagora
-
-=back
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.10.1 or,
-at your option, any later version of Perl 5 you may have available.
-
-=cut
